#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'general.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERAL_H
#define UI_GENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_General
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox3;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel3;
    QSlider *kcfg_StartHitPoints0;
    QSpinBox *spinBox_2;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel4;
    QSlider *kcfg_StartHitPoints1;
    QSpinBox *spinBox_3;
    QGroupBox *groupBox4;
    QHBoxLayout *hboxLayout2;
    QLabel *textLabel5;
    QSlider *kcfg_RefreshTime;
    QSpinBox *spinBox;
    QHBoxLayout *hboxLayout3;
    QGroupBox *groupBox1;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout4;
    QCheckBox *kcfg_Player0IsAi;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout5;
    QLabel *textLabel1;
    QComboBox *kcfg_AiDifficulty0;
    QGroupBox *groupBox2;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout6;
    QCheckBox *kcfg_Player1IsAi;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout7;
    QLabel *textLabel2;
    QComboBox *kcfg_AiDifficulty1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *General)
    {
        if (General->objectName().isEmpty())
            General->setObjectName(QStringLiteral("General"));
        General->resize(398, 441);
        vboxLayout = new QVBoxLayout(General);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        groupBox3 = new QGroupBox(General);
        groupBox3->setObjectName(QStringLiteral("groupBox3"));
        vboxLayout1 = new QVBoxLayout(groupBox3);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        textLabel3 = new QLabel(groupBox3);
        textLabel3->setObjectName(QStringLiteral("textLabel3"));

        hboxLayout->addWidget(textLabel3);

        kcfg_StartHitPoints0 = new QSlider(groupBox3);
        kcfg_StartHitPoints0->setObjectName(QStringLiteral("kcfg_StartHitPoints0"));
        kcfg_StartHitPoints0->setMinimum(1);
        kcfg_StartHitPoints0->setValue(99);
        kcfg_StartHitPoints0->setSliderPosition(99);
        kcfg_StartHitPoints0->setOrientation(Qt::Horizontal);

        hboxLayout->addWidget(kcfg_StartHitPoints0);

        spinBox_2 = new QSpinBox(groupBox3);
        spinBox_2->setObjectName(QStringLiteral("spinBox_2"));
        spinBox_2->setValue(99);

        hboxLayout->addWidget(spinBox_2);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        textLabel4 = new QLabel(groupBox3);
        textLabel4->setObjectName(QStringLiteral("textLabel4"));

        hboxLayout1->addWidget(textLabel4);

        kcfg_StartHitPoints1 = new QSlider(groupBox3);
        kcfg_StartHitPoints1->setObjectName(QStringLiteral("kcfg_StartHitPoints1"));
        kcfg_StartHitPoints1->setMinimum(1);
        kcfg_StartHitPoints1->setValue(99);
        kcfg_StartHitPoints1->setSliderPosition(99);
        kcfg_StartHitPoints1->setOrientation(Qt::Horizontal);

        hboxLayout1->addWidget(kcfg_StartHitPoints1);

        spinBox_3 = new QSpinBox(groupBox3);
        spinBox_3->setObjectName(QStringLiteral("spinBox_3"));
        spinBox_3->setValue(99);

        hboxLayout1->addWidget(spinBox_3);


        vboxLayout1->addLayout(hboxLayout1);


        vboxLayout->addWidget(groupBox3);

        groupBox4 = new QGroupBox(General);
        groupBox4->setObjectName(QStringLiteral("groupBox4"));
        hboxLayout2 = new QHBoxLayout(groupBox4);
#ifndef UI_Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout2->setContentsMargins(9, 9, 9, 9);
#endif
        hboxLayout2->setObjectName(QStringLiteral("hboxLayout2"));
        textLabel5 = new QLabel(groupBox4);
        textLabel5->setObjectName(QStringLiteral("textLabel5"));

        hboxLayout2->addWidget(textLabel5);

        kcfg_RefreshTime = new QSlider(groupBox4);
        kcfg_RefreshTime->setObjectName(QStringLiteral("kcfg_RefreshTime"));
        kcfg_RefreshTime->setMinimum(10);
        kcfg_RefreshTime->setMaximum(100);
        kcfg_RefreshTime->setValue(33);
        kcfg_RefreshTime->setOrientation(Qt::Horizontal);

        hboxLayout2->addWidget(kcfg_RefreshTime);

        spinBox = new QSpinBox(groupBox4);
        spinBox->setObjectName(QStringLiteral("spinBox"));
        spinBox->setMaximum(100);
        spinBox->setMinimum(10);
        spinBox->setValue(33);

        hboxLayout2->addWidget(spinBox);


        vboxLayout->addWidget(groupBox4);

        hboxLayout3 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout3->setSpacing(6);
#endif
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName(QStringLiteral("hboxLayout3"));
        groupBox1 = new QGroupBox(General);
        groupBox1->setObjectName(QStringLiteral("groupBox1"));
        vboxLayout2 = new QVBoxLayout(groupBox1);
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout2->setObjectName(QStringLiteral("vboxLayout2"));
        hboxLayout4 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout4->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout4->setObjectName(QStringLiteral("hboxLayout4"));
        kcfg_Player0IsAi = new QCheckBox(groupBox1);
        kcfg_Player0IsAi->setObjectName(QStringLiteral("kcfg_Player0IsAi"));

        hboxLayout4->addWidget(kcfg_Player0IsAi);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout4->addItem(spacerItem);


        vboxLayout2->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout5->setSpacing(6);
#endif
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        hboxLayout5->setObjectName(QStringLiteral("hboxLayout5"));
        textLabel1 = new QLabel(groupBox1);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));
        textLabel1->setEnabled(false);

        hboxLayout5->addWidget(textLabel1);

        kcfg_AiDifficulty0 = new QComboBox(groupBox1);
        kcfg_AiDifficulty0->setObjectName(QStringLiteral("kcfg_AiDifficulty0"));
        kcfg_AiDifficulty0->setEnabled(false);

        hboxLayout5->addWidget(kcfg_AiDifficulty0);


        vboxLayout2->addLayout(hboxLayout5);


        hboxLayout3->addWidget(groupBox1);

        groupBox2 = new QGroupBox(General);
        groupBox2->setObjectName(QStringLiteral("groupBox2"));
        QSizePolicy sizePolicy(static_cast<QSizePolicy::Policy>(5), static_cast<QSizePolicy::Policy>(4));
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox2->sizePolicy().hasHeightForWidth());
        groupBox2->setSizePolicy(sizePolicy);
        vboxLayout3 = new QVBoxLayout(groupBox2);
#ifndef UI_Q_OS_MAC
        vboxLayout3->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout3->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout3->setObjectName(QStringLiteral("vboxLayout3"));
        hboxLayout6 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout6->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout6->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout6->setObjectName(QStringLiteral("hboxLayout6"));
        kcfg_Player1IsAi = new QCheckBox(groupBox2);
        kcfg_Player1IsAi->setObjectName(QStringLiteral("kcfg_Player1IsAi"));

        hboxLayout6->addWidget(kcfg_Player1IsAi);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout6->addItem(spacerItem1);


        vboxLayout3->addLayout(hboxLayout6);

        hboxLayout7 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout7->setSpacing(6);
#endif
        hboxLayout7->setContentsMargins(0, 0, 0, 0);
        hboxLayout7->setObjectName(QStringLiteral("hboxLayout7"));
        textLabel2 = new QLabel(groupBox2);
        textLabel2->setObjectName(QStringLiteral("textLabel2"));
        textLabel2->setEnabled(false);

        hboxLayout7->addWidget(textLabel2);

        kcfg_AiDifficulty1 = new QComboBox(groupBox2);
        kcfg_AiDifficulty1->setObjectName(QStringLiteral("kcfg_AiDifficulty1"));
        kcfg_AiDifficulty1->setEnabled(false);

        hboxLayout7->addWidget(kcfg_AiDifficulty1);


        vboxLayout3->addLayout(hboxLayout7);


        hboxLayout3->addWidget(groupBox2);


        vboxLayout->addLayout(hboxLayout3);

        spacerItem2 = new QSpacerItem(20, 91, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem2);


        retranslateUi(General);
        QObject::connect(kcfg_Player0IsAi, SIGNAL(toggled(bool)), textLabel1, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_Player0IsAi, SIGNAL(toggled(bool)), kcfg_AiDifficulty0, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_Player1IsAi, SIGNAL(toggled(bool)), textLabel2, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_Player1IsAi, SIGNAL(toggled(bool)), kcfg_AiDifficulty1, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_StartHitPoints0, SIGNAL(valueChanged(int)), spinBox_2, SLOT(setValue(int)));
        QObject::connect(spinBox_2, SIGNAL(valueChanged(int)), kcfg_StartHitPoints0, SLOT(setValue(int)));
        QObject::connect(kcfg_StartHitPoints1, SIGNAL(valueChanged(int)), spinBox_3, SLOT(setValue(int)));
        QObject::connect(spinBox_3, SIGNAL(valueChanged(int)), kcfg_StartHitPoints1, SLOT(setValue(int)));
        QObject::connect(kcfg_RefreshTime, SIGNAL(valueChanged(int)), spinBox, SLOT(setValue(int)));
        QObject::connect(spinBox, SIGNAL(valueChanged(int)), kcfg_RefreshTime, SLOT(setValue(int)));

        kcfg_AiDifficulty0->setCurrentIndex(1);
        kcfg_AiDifficulty1->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(General);
    } // setupUi

    void retranslateUi(QWidget *General)
    {
        groupBox3->setTitle(tr2i18n("Hit Points", Q_NULLPTR));
        textLabel3->setText(tr2i18n("Red player:", Q_NULLPTR));
        textLabel4->setText(tr2i18n("Blue player:", Q_NULLPTR));
        groupBox4->setTitle(tr2i18n("Graphics", Q_NULLPTR));
        textLabel5->setText(tr2i18n("Refresh time:", Q_NULLPTR));
        groupBox1->setTitle(tr2i18n("Red Player", Q_NULLPTR));
        kcfg_Player0IsAi->setText(tr2i18n("Player is AI", Q_NULLPTR));
        textLabel1->setText(tr2i18n("Difficulty:", Q_NULLPTR));
        kcfg_AiDifficulty0->clear();
        kcfg_AiDifficulty0->insertItems(0, QStringList()
         << tr2i18n("Trainee", Q_NULLPTR)
         << tr2i18n("Normal", Q_NULLPTR)
         << tr2i18n("Hard", Q_NULLPTR)
         << tr2i18n("Insane", Q_NULLPTR)
        );
        groupBox2->setTitle(tr2i18n("Blue Player", Q_NULLPTR));
        kcfg_Player1IsAi->setText(tr2i18n("Player is AI", Q_NULLPTR));
        textLabel2->setText(tr2i18n("Difficulty:", Q_NULLPTR));
        kcfg_AiDifficulty1->clear();
        kcfg_AiDifficulty1->insertItems(0, QStringList()
         << tr2i18n("Trainee", Q_NULLPTR)
         << tr2i18n("Normal", Q_NULLPTR)
         << tr2i18n("Hard", Q_NULLPTR)
         << tr2i18n("Insane", Q_NULLPTR)
        );
        Q_UNUSED(General);
    } // retranslateUi

};

namespace Ui {
    class General: public Ui_General {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERAL_H

