/****************************************************************************
** Meta object code from reading C++ file 'mainview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kspaceduel-17.08.3/mainview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MyMainView_t {
    QByteArrayData data[23];
    char stringdata0[166];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MyMainView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MyMainView_t qt_meta_stringdata_MyMainView = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MyMainView"
QT_MOC_LITERAL(1, 11, 9), // "hitPoints"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 2), // "pn"
QT_MOC_LITERAL(4, 25, 2), // "hp"
QT_MOC_LITERAL(5, 28, 6), // "energy"
QT_MOC_LITERAL(6, 35, 2), // "en"
QT_MOC_LITERAL(7, 38, 4), // "wins"
QT_MOC_LITERAL(8, 43, 1), // "w"
QT_MOC_LITERAL(9, 45, 13), // "setStatusText"
QT_MOC_LITERAL(10, 59, 3), // "str"
QT_MOC_LITERAL(11, 63, 2), // "id"
QT_MOC_LITERAL(12, 66, 8), // "newRound"
QT_MOC_LITERAL(13, 75, 7), // "newGame"
QT_MOC_LITERAL(14, 83, 11), // "togglePause"
QT_MOC_LITERAL(15, 95, 5), // "pause"
QT_MOC_LITERAL(16, 101, 6), // "resume"
QT_MOC_LITERAL(17, 108, 5), // "start"
QT_MOC_LITERAL(18, 114, 4), // "stop"
QT_MOC_LITERAL(19, 119, 9), // "gameSetup"
QT_MOC_LITERAL(20, 129, 13), // "closeSettings"
QT_MOC_LITERAL(21, 143, 10), // "readConfig"
QT_MOC_LITERAL(22, 154, 11) // "writeConfig"

    },
    "MyMainView\0hitPoints\0\0pn\0hp\0energy\0"
    "en\0wins\0w\0setStatusText\0str\0id\0newRound\0"
    "newGame\0togglePause\0pause\0resume\0start\0"
    "stop\0gameSetup\0closeSettings\0readConfig\0"
    "writeConfig"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MyMainView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   89,    2, 0x06 /* Public */,
       5,    2,   94,    2, 0x06 /* Public */,
       7,    2,   99,    2, 0x06 /* Public */,
       9,    2,  104,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,  109,    2, 0x0a /* Public */,
      13,    0,  110,    2, 0x0a /* Public */,
      14,    0,  111,    2, 0x0a /* Public */,
      15,    0,  112,    2, 0x0a /* Public */,
      16,    0,  113,    2, 0x0a /* Public */,
      17,    0,  114,    2, 0x0a /* Public */,
      18,    0,  115,    2, 0x0a /* Public */,
      19,    0,  116,    2, 0x0a /* Public */,
      20,    0,  117,    2, 0x0a /* Public */,
      21,    0,  118,    2, 0x0a /* Public */,
      22,    0,  119,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    4,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   10,   11,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MyMainView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MyMainView *_t = static_cast<MyMainView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->hitPoints((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->energy((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->wins((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->setStatusText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->newRound(); break;
        case 5: _t->newGame(); break;
        case 6: _t->togglePause(); break;
        case 7: _t->pause(); break;
        case 8: _t->resume(); break;
        case 9: _t->start(); break;
        case 10: _t->stop(); break;
        case 11: _t->gameSetup(); break;
        case 12: _t->closeSettings(); break;
        case 13: _t->readConfig(); break;
        case 14: _t->writeConfig(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (MyMainView::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MyMainView::hitPoints)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MyMainView::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MyMainView::energy)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MyMainView::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MyMainView::wins)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (MyMainView::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MyMainView::setStatusText)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject MyMainView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_MyMainView.data,
      qt_meta_data_MyMainView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MyMainView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MyMainView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MyMainView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MyMainView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void MyMainView::hitPoints(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MyMainView::energy(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void MyMainView::wins(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void MyMainView::setStatusText(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
